Struct NoisyFloat

pub struct NoisyFloat<F: Float, C: FloatChecker<F>> { /* private fields */ }
A floating point number with a restricted set of legal values.

Typical users will not need to access this struct directly, but can instead use the type aliases found in the module noisy_float::types. However, this struct together with a FloatChecker implementation can be used to define custom behavior.

The underlying float type is F, usually f32 or f64. Valid values for the float are determined by the float checker C. If an invalid value would ever be returned from a method on this type, the method will panic instead, using either assert! or debug_assert! as defined by the float checker. The exception to this rule is for methods that return an Option containing a NoisyFloat, in which case the result would be None if the value is invalid.

Implementations

Source

impl NoisyFloat<f32, NumChecker>

pub const fn unchecked_new(value: f32) -> Self

A const constructor that does not check whether value is valid.

WARNING: This constructor does not panic even in debug mode. As always, it is the user’s responsibility to ensure value is valid. Until Rust supports panics in const functions, this constructor is necessary to create a NoisyFloat in a const setting.

pub const fn const_raw(self) -> f32

A const function that returns the underlying float value.

Source

impl NoisyFloat<f64, NumChecker>

pub const fn unchecked_new(value: f64) -> Self

A const constructor that does not check whether value is valid.

WARNING: This constructor does not panic even in debug mode. As always, it is the user’s responsibility to ensure value is valid. Until Rust supports panics in const functions, this constructor is necessary to create a NoisyFloat in a const setting.

pub const fn const_raw(self) -> f64

A const function that returns the underlying float value.

Source

impl NoisyFloat<f32, FiniteChecker>

pub const fn unchecked_new(value: f32) -> Self

A const constructor that does not check whether value is valid.

WARNING: This constructor does not panic even in debug mode. As always, it is the user’s responsibility to ensure value is valid. Until Rust supports panics in const functions, this constructor is necessary to create a NoisyFloat in a const setting.

pub const fn const_raw(self) -> f32

A const function that returns the underlying float value.

Source

impl NoisyFloat<f64, FiniteChecker>

pub const fn unchecked_new(value: f64) -> Self

A const constructor that does not check whether value is valid.

WARNING: This constructor does not panic even in debug mode. As always, it is the user’s responsibility to ensure value is valid. Until Rust supports panics in const functions, this constructor is necessary to create a NoisyFloat in a const setting.

pub const fn const_raw(self) -> f64

A const function that returns the underlying float value.

Source

impl<F: Float, C: FloatChecker<F>> NoisyFloat<F, C>

pub fn new(value: F) -> Self

Constructs a NoisyFloat with the given value.

Uses the FloatChecker to assert that the value is valid.

pub fn try_new(value: F) -> Option<Self>

Tries to construct a NoisyFloat with the given value.

Returns None if the value is invalid.

pub fn borrowed(value: &F) -> &Self

Converts the value in-place to a reference to a NoisyFloat.

Uses the FloatChecker to assert that the value is valid.

pub fn try_borrowed(value: &F) -> Option<&Self>

Tries to convert the value in-place to a reference to a NoisyFloat.

Returns None if the value is invalid.

pub fn borrowed_mut(value: &mut F) -> &mut Self

Converts the value in-place to a mutable reference to a NoisyFloat.

Uses the FloatChecker to assert that the value is valid.

pub fn try_borrowed_mut(value: &mut F) -> Option<&mut Self>

Tries to convert the value in-place to a mutable reference to a NoisyFloat.

Returns None if the value is invalid.

pub fn from_f32(value: f32) -> Self

Constructs a NoisyFloat with the given f32 value.

May panic not only by the FloatChecker but also by unwrapping the result of a NumCast invocation for type F, although the later should not occur in normal situations.

pub fn from_f64(value: f64) -> Self

Constructs a NoisyFloat with the given f64 value.

May panic not only by the FloatChecker but also by unwrapping the result of a NumCast invocation for type F, although the later should not occur in normal situations.

pub fn raw(self) -> F

Returns the underlying float value.

pub fn min(self, other: Self) -> Self

Compares and returns the minimum of two values.

This method exists to disambiguate between num_traits::Float.min and std::cmp::Ord.min.

pub fn max(self, other: Self) -> Self

Compares and returns the maximum of two values.

This method exists to disambiguate between num_traits::Float.max and std::cmp::Ord.max.